(productionconfiguration)=

# Production Configuration

Modules provide functionality to configure a simulation production.
This includes the derivation of energy, viewcone radius, and core scatter ranges and
the calculation of the number of events to be simulated given a pre-determined metric.

(calculate-statistical-errors-grid-point)=

## calculate_statistical_errors_grid_point

```{eval-rst}
.. automodule:: production_configuration.calculate_statistical_errors_grid_point
   :members:
```

(event-scaler)=

## event_scaler

```{eval-rst}
.. automodule:: production_configuration.event_scaler
   :members:
```

(extract-mc-event-data)=

## extract_mc_event_data

```{eval-rst}
.. automodule:: production_configuration.extract_mc_event_data
   :members:
```

(generate-simulation-config)=

## generate_simulation_config

```{eval-rst}
.. automodule:: production_configuration.generate_simulation_config
   :members:
```

(interpolation-handler)=

## interpolation_handler

```{eval-rst}
.. automodule:: production_configuration.interpolation_handler
   :members:
```

(derive-corsika-limits)=

## derive_corsika_limits

```{eval-rst}
.. automodule:: production_configuration.derive_corsika_limits
   :members:
```
